
/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include <usart.h>
#include "system\typedefs.h"

#include "system\usb\usb.h"

#include "io_cfg.h"             // I/O pin mapping
#include "user\user.h"

/** V A R I A B L E S ********************************************************/
#pragma udata
byte counter;

DATA_PACKET dataPacket;

/** P R I V A T E  P R O T O T Y P E S ***************************************/

void BlinkUSBStatus(void);
void ReadPOT(void);
void ServiceRequests(void);
BOOL UBit(unsigned char byteB, unsigned char bit0);


/** D E C L A R A T I O N S **************************************************/
#pragma code
void UserInit(void)
{
    // 0 - output
    TRISA &= 0b00101111; LATA &= 0x00;
    TRISB &= 0b00011111; LATB &= 0x00;
    TRISC &= 0b00111000; LATC &= 0x00;
    ADCON2=0b10111100;
}

void ProcessIO(void)
{   
    BlinkUSBStatus();
    if((usb_device_state < CONFIGURED_STATE)||(UCONbits.SUSPND==1)) return;
    ServiceRequests();
}

void ReadPOT(void)
{
    ADCON0bits.GO = 1;
    while(ADCON0bits.NOT_DONE);
    return;
}

void ServiceRequests(void)
{
    byte index;
    
    if(USBGenRead((byte*)&dataPacket,sizeof(dataPacket)))
    {
        counter = 0;
        if(dataPacket.CMD == RD_POT){		

		  LATCbits.LATC0 = UBit(dataPacket.ID, 0);
		  LATCbits.LATC1 = UBit(dataPacket.ID, 1);
		  LATCbits.LATC2 = UBit(dataPacket.ID, 2);
		  LATCbits.LATC6 = UBit(dataPacket.ID, 3);
		  LATCbits.LATC7 = UBit(dataPacket.ID, 4);
		  LATBbits.LATB5 = UBit(dataPacket.ID, 5);
		  LATBbits.LATB6 = UBit(dataPacket.ID, 6);
		  LATBbits.LATB7 = UBit(dataPacket.ID, 7);
		  
		  for(counter=1; counter < 20; counter = counter + 2){
			 switch(counter){
			 	case 1:
					ADCON0=0b00000001;
					break;
				case 3:
					ADCON0=0b00000101;
					break;
				case 5:
					ADCON0=0b00001001;
					break;
				case 7:
					ADCON0=0b00001101;
					break;
				case 9:
					ADCON0=0b00010001;
					break;
				case 11:
					ADCON0=0b00100001;
					break;
				case 13:
					ADCON0=0b00100101;
					break;
				case 15:
					ADCON0=0b00101001;
					break;
				case 17:
					ADCON0=0b00101101;
					break;
				case 19:
					ADCON0=0b00110001;
					break;
			 }
		  	ReadPOT();
                	dataPacket._byte[counter] = ADRESL;
                	dataPacket._byte[counter+1] = ADRESH;
		  }
		  LATAbits.LATA4 = 1;	// BUSY  
                counter=0x15;	// 21 
	}else if(dataPacket.CMD == RESET) Reset();	


        if(counter != 0){
            if(!mUSBGenTxIsBusy())
                USBGenWrite((byte*)&dataPacket,counter);
        }
    }

}





void BlinkUSBStatus(void)
{
    static word led_count=0;
    
    if(led_count == 0){
	  led_count = 50000U;
	  LATAbits.LATA4 = 0;	// BUSY 
    }
    if(led_count == 200)LATAbits.LATA4 = 1;
    led_count--;
}



BOOL UBit(unsigned char byteB, unsigned char bit0)
{
	if(((byteB >> bit0) & 1) > 0)
	{
		return 1;
	}else{
		return 0;
	}
}

